==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/co/gco519CErrorHandling.h <==
/*!***************************************************************************

  module      : gco519CErrorHandling.h

  -------------------------------------------------------------------------

  responsible : FerdiF

  special area: C++ SQL Class   
  description : Implementation of co519CErrorHandling
				
  
  last changed: 2000-03-08  11:22
  see also    : 

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 2000



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/

#ifndef GCO519CERRORHANDLING_H
#define GCO519CERRORHANDLING_H

#ifndef GGG00_H
#include "ggg00.h"
#endif

class  co51CSqlSessionContext;

#define e_dbconnect_notok            -27014 
#define e_dbconnection_down          -27015 
#define e_dbshutdown                 -27016
#define e_too_many_users             -27017
#define e_notok                      -27018
 
class  co519CErrorHandling
{
  static const char* m_error_msg[20];
public:  
  co519CErrorHandling();
  const char* getErrorDesc( tgg00_BasisError e ); 
};



#endif

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/co/gco519CErrorHandling.h <==
/*!***************************************************************************

  module      : gco519CErrorHandling.h

  -------------------------------------------------------------------------

  responsible : FerdiF

  special area: C++ SQL Class   
  description : Implementation of co519CErrorHandling
				
  
  last changed: 2000-03-08  11:22
  see also    : 

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 2000



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/

#ifndef GCO519CERRORHANDLING_H
#define GCO519CERRORHANDLING_H

#ifndef GGG00_H
#include "ggg00.h"
#endif

class  co51CSqlSessionContext;

#define e_dbconnect_notok            -27014 
#define e_dbconnection_down          -27015 
#define e_dbshutdown                 -27016
#define e_too_many_users             -27017
#define e_notok                      -27018
#define e_nonascii_char              -27020 /* PTS 1121341 */

#define SQLCLS_ErrCnt 21 /* number of SQL class errors, PTS 1121341 */
 
class  co519CErrorHandling
{
  static const char* m_error_msg[SQLCLS_ErrCnt];
public:  
  co519CErrorHandling();
  const char* getErrorDesc( tgg00_BasisError e ); 
};



#endif
